==> moodle_1.3.1.orig.tar.gz: moodle/lang/nl/dialogue.php <==
<?PHP // $Id: dialogue.php,v 1.4 2003/12/27 13:05:46 koenr Exp $ 
      // dialogue.php - created with Moodle 1.2 development (2003121500)


$string['addmynewentries'] = 'Voeg mijn nieuwe boodschappen toe';
$string['addmynewentry'] = 'Voeg mijn nieuwe boodschap toe';
$string['addsubject'] = 'Voeg onderwerp toe';
$string['allowmultiple'] = 'Sta meer dan n dialoog met dezelfde persoon toe';
$string['allowstudentdialogues'] = 'Sta dialoog tussen leerlingen toe';
$string['close'] = 'Sluit';
$string['closed'] = 'Gesloten';
$string['confirmclosure'] = 'Je gaat de dialoog met $a sluiten. Gesloten dialogen kunnen niet meer geopend worden. Als je deze dialoog sluit, kun je hem nog wel bekijken, maar je kunt er niets meer aan toevoegen. Je zult een nieuwe dialoog moeten starten om met deze persoon verder te &quot;praten&quot;.<br/><br/>Ben je er zeker van dat je deze dialoog wil sluiten? ';
$string['deleteafter'] = 'Verwijder gesloten dialogen na (dagen)';
$string['dialogueclosed'] = 'Dialoog gesloten';
$string['dialogueintro'] = 'Inleiding dialoog';
$string['dialoguemail'] = '$a->userform heeft een niewe boodschap in je dialoog gepost voor \'$a->dialoog\'
Je kunt het zien verschijnen bij je dialoogboodschap:
$a->url';
$string['dialoguemailhtml'] = '$a->userform heeft een nieuwe boodschap in je dialoog gepost voor \'<i>$a->dialogue</i>\'<br/><br/>
Je kunt zien dat het aan jouw <a href=\"$a->url\">dialoog</a> toegevoegd is ';
$string['dialoguename'] = 'Dialoog naam';
$string['dialogueopened'] = 'Dialoog geopend met $a';
$string['dialoguewith'] = 'Dialoog met $a';
$string['everybody'] = 'Iedereen';
$string['furtherinformation'] = 'Meer informatie';
$string['lastentry'] = 'Laatste item';
$string['maildefault'] = 'Standaard e-mail zenden';
$string['modulename'] = 'Dialoog';
$string['modulenameplural'] = 'Dialogen';
$string['namehascloseddialogue'] = '$a heeft de dialoog gesloten';
$string['newdialogueentries'] = 'Nieuwe dialoog items';
$string['newentry'] = 'Nieuw item';
$string['noavailablepeople'] = 'Er is niemand om een Dialoog mee te starten';
$string['nopersonchosen'] = 'Niemand gekozen';
$string['nosubject'] = 'Geen onderwerp toegevoegd';
$string['notextentered'] = 'Geen tekst ingevoegd';
$string['notstarted'] = 'Je bent deze dialoog nog niet begonnen';
$string['notyetseen'] = 'Nog niet bekeken';
$string['numberofentries'] = 'Aantal boodschappen';
$string['numberofentriesadded'] = 'Aantal boodschappen toegevoegd: $a';
$string['of'] = 'van';
$string['onwrote'] = 'Op $a schreef';
$string['onyouwrote'] = 'Op $a schreef jij';
$string['open'] = 'Open';
$string['openadialoguewith'] = 'Open een dialoog met';
$string['opendialogue'] = 'Open dialoog';
$string['opendialogueentries'] = 'Open de boodschappen van de dialoog';
$string['pane0'] = 'Open een dialoog';
$string['pane1'] = '$a dialogen te beantwoorden';
$string['pane1one'] = '1 dialoog te beantwoorden';
$string['pane2'] = '$a dialogen wachten nog op antwoord';
$string['pane2one'] = '1 dialoog wacht nog op antwoord';
$string['pane3'] = '$a gesloten dialogen';
$string['pane3one'] = '1 gesloten dialoog';
$string['seen'] = '$a geleden gezien';
$string['sendmailmessages'] = 'Stuur e-mails over mijn nieuwe boodschappen';
$string['status'] = 'Status';
$string['studenttostudent'] = 'Leerling - leerling';
$string['subject'] = 'Onderwerp';
$string['subjectadded'] = 'Onderwerp toegevoegd';
$string['teachertostudent'] = 'Leraar - leerling';
$string['typefirstentry'] = 'Typ het eerste item hier';
$string['typefollowup'] = 'Typ de opvolging hier';
$string['typeofdialogue'] = 'Type dialoog';
$string['typereply'] = 'typ het antwoord hier';
$string['viewallentries'] = 'bekijk $a dialoogboodschappen';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/nl/dialogue.php <==
<?PHP // $Id$ 
      // dialogue.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['addmynewentries'] = 'Voeg mijn nieuwe boodschappen toe';
$string['addmynewentry'] = 'Voeg mijn nieuwe boodschap toe';
$string['addsubject'] = 'Voeg onderwerp toe';
$string['allowmultiple'] = 'Sta meer dan n dialoog met dezelfde persoon toe';
$string['allowstudentdialogues'] = 'Sta dialoog tussen leerlingen toe';
$string['close'] = 'Sluit';
$string['closed'] = 'Gesloten';
$string['confirmclosure'] = 'Je gaat de dialoog met $a sluiten. Gesloten dialogen kunnen niet meer geopend worden. Als je deze dialoog sluit, kun je hem nog wel bekijken, maar je kunt er niets meer aan toevoegen. Je zult een nieuwe dialoog moeten starten om met deze persoon verder te \"praten\".<br /><br />Ben je er zeker van dat je deze dialoog wil sluiten? ';
$string['deleteafter'] = 'Verwijder gesloten dialogen na (dagen)';
$string['dialogueclosed'] = 'Dialoog gesloten';
$string['dialogueintro'] = 'Inleiding dialoog';
$string['dialoguemail'] = '$a->userfrom heeft een nieuwe boodschap in je dialoog gepost voor \'$a->dialoog\'
Je kunt het zien verschijnen bij je dialoogboodschap:
$a->url';
$string['dialoguemailhtml'] = '$a->userfrom heeft een nieuwe boodschap in je dialoog gepost voor \'<i>$a->dialogue</i>\'<br /><br />
Je kunt zien dat het aan jouw <a href=\"$a->url\">dialoog</a> toegevoegd is ';
$string['dialoguename'] = 'Naam dialoog';
$string['dialogueopened'] = 'Dialoog geopend met $a';
$string['dialoguewith'] = 'Dialoog met $a';
$string['everybody'] = 'Iedereen';
$string['furtherinformation'] = 'Meer informatie';
$string['lastentry'] = 'Laatste item';
$string['maildefault'] = 'Standaard e-mail zenden';
$string['mailnotification'] = 'E-mail notificatie';
$string['modulename'] = 'Dialoog';
$string['modulenameplural'] = 'Dialogen';
$string['namehascloseddialogue'] = '$a heeft de dialoog gesloten';
$string['newdialogueentries'] = 'Nieuwe dialoogitems';
$string['newentry'] = 'Nieuw item';
$string['noavailablepeople'] = 'Er is niemand om een dialoog mee te starten';
$string['nopersonchosen'] = 'Niemand gekozen';
$string['nosubject'] = 'Geen onderwerp toegevoegd';
$string['notextentered'] = 'Geen tekst ingevoegd';
$string['notstarted'] = 'Je bent deze dialoog nog niet begonnen';
$string['notyetseen'] = 'Nog niet bekeken';
$string['numberofentries'] = 'Aantal boodschappen';
$string['numberofentriesadded'] = 'Aantal boodschappen toegevoegd: $a';
$string['of'] = 'van';
$string['onwrote'] = 'Op $a schreef';
$string['onyouwrote'] = 'Op $a schreef jij';
$string['open'] = 'Open';
$string['openadialoguewith'] = 'Open een dialoog met';
$string['opendialogue'] = 'Open dialoog';
$string['opendialogueentries'] = 'Open de boodschappen van de dialoog';
$string['pane0'] = 'Open een dialoog';
$string['pane1'] = '$a dialogen te beantwoorden';
$string['pane1one'] = '1 dialoog te beantwoorden';
$string['pane2'] = '$a dialogen wachten nog op antwoord';
$string['pane2one'] = '1 dialoog wacht nog op antwoord';
$string['pane3'] = '$a gesloten dialogen';
$string['pane3one'] = '1 gesloten dialoog';
$string['seen'] = '$a geleden gezien';
$string['sendmailmessages'] = 'Stuur e-mails over mijn nieuwe boodschappen';
$string['status'] = 'Status';
$string['studenttostudent'] = 'Leerling - leerling';
$string['subject'] = 'Onderwerp';
$string['subjectadded'] = 'Onderwerp toegevoegd';
$string['teachertostudent'] = 'Leraar - leerling';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Nederlands';
$string['typefirstentry'] = 'Typ het eerste item hier';
$string['typefollowup'] = 'Typ de opvolging hier';
$string['typeofdialogue'] = 'Type dialoog';
$string['typereply'] = 'typ het antwoord hier';
$string['viewallentries'] = 'bekijk $a dialoogboodschappen';

?>
